/*
Copyright (C) <2008>  Guido Steiner and Detlef Wolf
contact: fam@wolfol.de
This is free software -- GNU LGPL license applies.
see http://www.gnu.org/licenses/lgpl.txt for details
*/

import javax.swing.JPanel; 

import java.awt.Graphics;  
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;

public class PendulumPanel extends JPanel {

  PendulumModel m ;
  Font font ;
 
  public PendulumPanel(PendulumModel m) {
    this.m = m ;
    setPreferredSize(new Dimension(400,400)) ;
    font = new Font(null, Font.PLAIN, 20) ;
  }

  int xCoordScreen(double x) {
    return (int)(x*900.0+170.0);
  }

  int yCoordScreen(double y) {
    return (int)(170.0-y*900.0);
  }

  void drawEnd(Graphics g, Color c, double x, double y) {
    int r = 9 ;
    g.setColor(c) ;
    g.drawOval( xCoordScreen(x)-r/2, yCoordScreen(y)-r/2 , r, r) ;
  }

  void drawStick(Graphics g, Color c, double x1, double y1, double x2, double y2 ) {
    g.setColor(c) ;
    g.drawLine(xCoordScreen(x1), yCoordScreen(y1), xCoordScreen(x2), yCoordScreen(y2)) ;
  }

  void drawLabel(Graphics g, Color c, String s, double x, double y ) {
    g.setColor(c) ;
    g.drawString(s, xCoordScreen(x), yCoordScreen(y)) ;
  }

  public void paintComponent(Graphics g) {
    super.paintComponent(g);
    setFont(font) ;
   
    // end points of the pheripheral pendulums
    double x1 ;
    double y1 ;
    double x2 ;
    double y2 ;
    double x3 ;
    double y3 ;

    // end points of the central pendulum
    double X1 ;
    double Y1 ;
    double X2 ;
    double Y2 ;
    double X3 ;
    double Y3 ;
    
    // calculate points from angles and lengthes
    X1 = -m.a*Math.cos(m.t0) ;
    Y1 = -m.a*Math.sin(m.t0) ;
    X2 = m.b*Math.sin(m.t0) ;
    Y2 = -m.b*Math.cos(m.t0) ;
    X3 = -X1 ;
    Y3 = -Y1 ;

    x1 = -m.a*Math.cos(m.t0)+m.l1*Math.sin(m.t1) ;
    y1 = -m.a*Math.sin(m.t0)-m.l1*Math.cos(m.t1) ;
    x2 = m.b*Math.sin(m.t0)+m.l2*Math.sin(m.t2) ;
    y2 = -m.b*Math.cos(m.t0)-m.l2*Math.cos(m.t2) ;
    x3 = m.a*Math.cos(m.t0)+m.l3*Math.sin(m.t3) ;
    y3 = m.a*Math.sin(m.t0)-m.l3*Math.cos(m.t3) ;
   
    if (m.reveal) {
      drawStick( g,Color.orange,X1,Y1,X3,Y3);
      drawStick( g,Color.orange,0.0,0.0,X2,Y2);
      
      drawStick( g,Color.blue,X1,Y1,x1,y1);
      drawStick( g,Color.red,X2,Y2,x2,y2);
      drawStick( g,Color.green,X3,Y3,x3,y3);

      drawEnd(g, Color.blue, x1, y1) ;
      drawEnd(g, Color.red, x2, y2) ;
      drawEnd(g, Color.green, x3, y3) ;

    }
    else {
      drawLabel(g, Color.blue, "Happy", x1, y1) ;
      drawLabel(g, Color.red, "New Year", x2, y2) ;
      drawLabel(g, Color.green, "2009 !", x3, y3) ;
    }
  }

}

